aboutsummaryrefslogtreecommitdiffstats
path: root/epan/dissectors/packet-llc.c
diff options
context:
space:
mode:
authorJaap Keuter <jaap.keuter@xs4all.nl>2008-04-10 23:56:10 +0000
committerJaap Keuter <jaap.keuter@xs4all.nl>2008-04-10 23:56:10 +0000
commitf94b46363ea608ebee67f7a46a1eb66ed0775627 (patch)
treeec667d63d6a0e82894651e8c444b5ff3e2984930 /epan/dissectors/packet-llc.c
parentf35472dc08d4aab4953af2922c5a9b483cc032d9 (diff)
Turbocell dissector, initially by Colin Slater for Ethereal 0.10.7, extended with help from sample capture by Jerome Poulin.
svn path=/trunk/; revision=24886
Diffstat (limited to 'epan/dissectors/packet-llc.c')
-rw-r--r--epan/dissectors/packet-llc.c12
1 files changed, 10 insertions, 2 deletions
diff --git a/epan/dissectors/packet-llc.c b/epan/dissectors/packet-llc.c
index 726883fb99..a41ef4c25d 100644
--- a/epan/dissectors/packet-llc.c
+++ b/epan/dissectors/packet-llc.c
@@ -92,6 +92,7 @@ static dissector_handle_t eth_withoutfcs_handle;
static dissector_handle_t eth_withfcs_handle;
static dissector_handle_t fddi_handle;
static dissector_handle_t tr_handle;
+static dissector_handle_t turbo_handle;
static dissector_handle_t data_handle;
/*
@@ -210,6 +211,7 @@ http://www.cisco.com/univercd/cc/td/doc/product/software/ios113ed/113ed_cr/ibm_r
{ OUI_SIEMENS, "Siemens AG" },
{ OUI_APPLE_ATALK, "Apple (AppleTalk)" },
{ OUI_HP, "Hewlett-Packard" },
+ { OUI_TURBOCELL, "Karlnet (Turbocell)" },
{ 0, NULL }
};
@@ -685,6 +687,11 @@ dissect_snap(tvbuff_t *tvb, int offset, packet_info *pinfo, proto_tree *tree,
call_dissector(bpdu_handle, next_tvb, pinfo, tree);
break;
+ case OUI_TURBOCELL:
+ next_tvb = tvb_new_subset(tvb, offset+3, -1, -1);
+ call_dissector(turbo_handle, next_tvb, pinfo, tree);
+ break;
+
default:
/*
* Do we have information for this OUI?
@@ -871,14 +878,15 @@ proto_reg_handoff_llc(void)
dissector_handle_t llc_handle;
/*
* Get handles for the BPDU, Ethernet, FDDI, and Token Ring
* dissectors.
*/
bpdu_handle = find_dissector("bpdu");
eth_withoutfcs_handle = find_dissector("eth_withoutfcs");
eth_withfcs_handle = find_dissector("eth_withfcs");
fddi_handle = find_dissector("fddi");
tr_handle = find_dissector("tr");
+ turbo_handle = find_dissector("turbocell");
data_handle = find_dissector("data");
llc_handle = find_dissector("llc");
@@ -871,14 +878,15 @@ proto_reg_handoff_llc(void)
dissector_handle_t llc_handle;
/*
- * Get handles for the BPDU, Ethernet, FDDI, and Token Ring
- * dissectors.
+ * Get handles for the BPDU, Ethernet, FDDI, Token Ring and
+ * Turbocell dissectors.
*/
bpdu_handle = find_dissector("bpdu");